Approximate log-likelihood maximisation
alik_optim(
paroptim,
formula,
family = "gaussian",
data,
weights,
subset,
offset,
atsample,
corrfcn = "matern",
np,
betm0,
betQ0,
ssqdf,
ssqsc,
dispersion = 1,
longlat = FALSE,
control = list()
)The output from the function optim.
The "value" element is the log-likelihood, not the
negative log-likelihood.
A named list with the components "linkp", "phi", "omg", "kappa". Each component must be numeric with length 1, 2, or 3 with elements in increasing order. If the compontent's length is 1, then the corresponding parameter is considered to be fixed at that value. If 2, then the two numbers denote the lower and upper bounds for the optimisation of that parameter (infinities are allowed). If 3, these correspond to lower bound, starting value, upper bound for the estimation of that parameter.
A representation of the model in the form
response ~ terms.
The distribution of the response.
An optional data frame containing the variables in the model.
An optional vector of weights. Number of replicated samples for Gaussian and gamma, number of trials for binomial, time length for Poisson.
An optional vector specifying a subset of observations to be used in the fitting process.
See lm.
A formula in the form ~ x1 + x2 + ... + xd
with the coordinates of the sampled locations.
Spatial correlation function. See
geoBayes_correlation for details.
The number of integration points for the spatial
variance parameter sigma^2. The total number of points will be
2*np + 1.
Prior mean for beta (a vector or scalar).
Prior standardised precision (inverse variance) matrix. Can be a scalar, vector or matrix. The first two imply a diagonal with those elements. Set this to 0 to indicate a flat improper prior.
Degrees of freedom for the scaled inverse chi-square prior for the partial sill parameter.
Scale for the scaled inverse chi-square prior for the partial sill parameter.
The fixed dispersion parameter.
How to compute the distance between locations. If
FALSE, Euclidean distance, if TRUE Great Circle
distance. See spDists.
A list of control parameters for the optimisation.
See optim.
Uses the "L-BFGS-B" method of the function
optim to maximise the log-likelihood for the
parameters linkp, phi, omg, kappa.
Evangelou, E., & Roy, V. (2019). Estimation and prediction for spatial generalized linear mixed models with parametric links via reparameterized importance sampling. Spatial Statistics, 29, 289-315.