Learn R Programming

geoBayes (version 0.3.0)

bfse: Computation of standard errors for Bayes factors

Description

Compute the standard errors for the Bayes factors estimates.

Usage

bfse(pargrid, runs, nbatches, bfsize1 = 0.8, method = c("RL", "MW"),
  reference = 1, transf = FALSE, bmmcse.size = "sqroot")

Arguments

pargrid
A data frame with components "linkp", "phi", "omg", "kappa". Each row gives a combination of the parameters to compute the new standard errors.
runs
A list with outputs from the function mcsglmm or mcstrga.
nbatches
An integer scalar or vector of the same length as runs indicating the number of batches to create for computing the variance using the samples of the first stage.
bfsize1
A scalar or vector of the same length as runs with all integer values or all values in (0, 1]. How many samples (or what proportion of the sample) to use for estimating the Bayes factors at the first stage. The remaining sample will be used f
method
Which method to use to calculate the Bayes factors: Reverse logistic or Meng-Wong.
reference
Which model goes in the denominator.
transf
Whether to use the transformed sample mu for the computations. Otherwise it uses z.
bmmcse.size
Size for computing the batch means Monte-Carlo variance using the samples of the second stage.

Value

  • A list with components
    • pargridThe inputted pargrid augmented with the computed standard errors.
    • bfEstimateThe estimates of the Bayes factors
    • bfSigmaThe covariance matrix for the Bayes factors estimates.

Details

Uses the batch means method to compute the standard errors for Bayes factors.

References

Roy, V., Tan, A. and Flegal, J. (2015). Estimating standard errors for importance sampling estimators with multiple Markov chains. Technical report, Iowa State University.