Learn R Programming

geoBayes (version 0.7.4)

geoBayes_models: Models used in the geoBayes package

Description

This hidden variable contains a choice of models that can be fit with this package. The model can be chosen in the family input of the relevant function. This variable cannot be overwritten.

Usage

.geoBayes_models

Arguments

Format

An object of class data.frame with 12 rows and 7 columns.