rhizoctonia: Rhizoctonia root rot infections
Description
Rhizoctonia root rot infections.format
A data frame with 100 rows and 5 variables.source
www.biometrics.tibs.org/datasets/010434.txtDetails
A dataset containing the number of infected roots and the sample
coordinate. The data were collected by Dr Jim Cook at Washington
State University.- Xcoord Longitude of the sampling location.
- Ycoord Latitude of the sampling location.
- Total Total number of roots sampled at that location.
- Infected Number of infected roots found at that location.
- Yield Barley yield at that location. These data were
obtained by hand-harvesting a 4-square-meter area in the sampling
location. One observation is missing.
References
Zhang, H. (2002). On estimation and prediction for
spatial generalized linear mixed models. Biometrics, 58(1),
129-136.