Spatial joint log likelihood
sploglik(pargrid, runs, transf = c("no", "mu", "wo"))A matrix with number of rows the total number of samples in runs and number of columns the number of rows in pargrid. The [i,j] element of the matrix is the value of the loglikelihood at the ith sample when all samples in runs are put together evaluated at the jth parameter value.
A data frame with components "linkp", "phi", "omg", "kappa". Each row gives a combination of the parameters to compute the log-likelihood.
A list with outputs from the function
mcsglmm or mcstrga.
Whether to use a transformed sample for the
computations. If "no" or FALSE, it doesn't. If
"mu" or TRUE, it uses the samples for the mean. If
"wo" it uses an alternative transformation. The latter
can be used only for the families indicated by
.geoBayes_models$haswo.
Computes the joint log likelihood log f(y,T(z)|parameters) where T(z) is the transformation, for each (y,z) in runs and for parameters in pargrid up to a constant which does not depend on the parameters. The parameters beta and sigma^2 are integrated out.