Spatial joint log likelihood
sploglik_cross(runs, transf = c("no", "mu", "wo"))A matrix with number of rows the total number of samples
in runs and number of columns the length of runs. The
[i,j] element of the matrix is the value of the loglikelihood at
the ith sample when all samples in runs are put together evaluated
at the jth parameter value.
A list with outputs from the function
mcsglmm or mcstrga.
Whether to use a transformed sample for the
computations. If "no" or FALSE, it doesn't. If
"mu" or TRUE, it uses the samples for the mean. If
"wo" it uses an alternative transformation. The latter
can be used only for the families indicated by
.geoBayes_models$haswo. The input can also be a vector
(of the same length as runs to allow for different
transformation to be used when evaluating each likelihood.
Computes the joint log likelihood log f(y,T(z)|parameters) where T(z) is the transformation, for each (y,z) in runs and for parameters in runs up to a constant which does not depend on the parameters. The parameters beta and sigma^2 are integrated out.