Learn R Programming

geoBayes (version 0.7.4)

subset.geomcmc: Subset MCMC chain

Description

Return subset of MCMC chain.

Usage

# S3 method for geomcmc
subset(x, subset, ...)

Value

A similar object as x with the subsetted chain.

Arguments

x

Output from the functions mcsglmm or mcstrga.

subset

Logical or integer vector.

...

Further arguments to be passed to or from other methods.